@@ -571,7 +571,7 @@ void ActionManagerImpl::initTabWidget(TabWidget* tabWidget)
     action->setShortcut( QKeySequence::ZoomOut );
 
     QString actionname;
-    for (int i=1;i<10;i++) {
+    for (int i=1;i<10;++i) {
       actionname.sprintf("activate_tab_%02d", i);
       action = new KAction( i18n("Activate Tab %1", i),this );
       action->setShortcut( QKeySequence( QString::fromLatin1( "Alt+%1" ).arg( i ) ) );
