@@ -48,9 +48,9 @@
 
 #include "kernel/mailkernel.h"
 
-#include "addressvalidationjob.h"
+#include "job/addressvalidationjob.h"
 #include "kleo_util.h"
-#include "stringutil.h"
+#include "utils/stringutil.h"
 #ifndef KDEPIM_MOBILE_UI
 #include "templatesconfiguration.h"
 #endif
