@@ -31,7 +31,7 @@
 #include "mailserviceimpl.h"
 #include "mailserviceimpl.moc"
 #include <serviceadaptor.h>
-#include "composer.h"
+#include "editor/composer.h"
 #include "kmkernel.h"
 
 // kdepim includes
