@@ -52,13 +52,12 @@ QWidget *SieveActionBreak::createParamWidget( QWidget *parent ) const
 
 QString SieveActionBreak::code(QWidget *w) const
 {
-    QString result;
     const KLineEdit *name = w->findChild<KLineEdit*>(QLatin1String("name"));
     const QString nameStr = name->text();
     if (!nameStr.isEmpty()) {
-        result = QString::fromLatin1(":name \"%1\"").arg(nameStr);
+        return QString::fromLatin1("break :name \"%1\";").arg(nameStr);
     }
-    return QString::fromLatin1("break %1;").arg(result);
+    return QLatin1String("break;");
 }
 
 QString SieveActionBreak::help() const
