@@ -1,5 +1,5 @@
 /*
-  Copyright (c) 2013-2015 Montel Laurent <montel@kde.org>
+  Copyright (c) 2013 Montel Laurent <montel@kde.org>
 
   This program is free software; you can redistribute it and/or modify it
   under the terms of the GNU General Public License, version 2, as
@@ -26,13 +26,7 @@ class SelectImportanceCombobox : public KComboBox
 public:
     explicit SelectImportanceCombobox(QWidget *parent = 0);
     ~SelectImportanceCombobox();
-
     QString code() const;
-    void setCode(const QString &code, const QString &name, QString &error);
-
-Q_SIGNALS:
-    void valueChanged();
-
 private:
     void initialize();
 };
